Class: Rixl::Images::Item::WithImageItemRequestBuilder

Inherits:
MicrosoftKiotaAbstractions::BaseRequestBuilder
  • Object
show all
Defined in:
lib/images/item/with_image_item_request_builder.rb

Overview

Builds and executes requests for operations under imagesimageId

Instance Method Summary collapse

Constructor Details

#initialize(path_parameters, request_adapter) ⇒ Object

Instantiates a new WithImageItemRequestBuilder and sets the default values.

Parameters:

  • path_parameters

    Path parameters for the request

  • request_adapter

    The request adapter to use to execute the requests.



21
22
23
# File 'lib/images/item/with_image_item_request_builder.rb', line 21

def initialize(path_parameters, request_adapter)
    super(path_parameters, request_adapter, "{+baseurl}/images/{imageId}")
end

Instance Method Details

#delete(request_configuration = nil) ⇒ Object

delete an image by marking it as deleted

Parameters:

  • request_configuration (defaults to: nil)

    Configuration for the request such as headers, query parameters, and middleware options.

Returns:

  • a Fiber of void



29
30
31
32
33
34
35
36
37
38
39
40
# File 'lib/images/item/with_image_item_request_builder.rb', line 29

def delete(request_configuration=nil)
    request_info = self.to_delete_request_information(
        request_configuration
    )
    error_mapping = Hash.new
    error_mapping["400"] = lambda {|pn| Rixl::Models::Github_com_rixlhq_api_internal_errorsErrorResponse.create_from_discriminator_value(pn) }
    error_mapping["401"] = lambda {|pn| Rixl::Models::Github_com_rixlhq_api_internal_errorsErrorResponse.create_from_discriminator_value(pn) }
    error_mapping["403"] = lambda {|pn| Rixl::Models::Github_com_rixlhq_api_internal_errorsErrorResponse.create_from_discriminator_value(pn) }
    error_mapping["404"] = lambda {|pn| Rixl::Models::Github_com_rixlhq_api_internal_errorsErrorResponse.create_from_discriminator_value(pn) }
    error_mapping["500"] = lambda {|pn| Rixl::Models::Github_com_rixlhq_api_internal_errorsErrorResponse.create_from_discriminator_value(pn) }
    return @request_adapter.send_async(request_info, nil, error_mapping)
end

#get(request_configuration = nil) ⇒ Object

Retrieve an image by its ID for a specific project.

Parameters:

  • request_configuration (defaults to: nil)

    Configuration for the request such as headers, query parameters, and middleware options.

Returns:

  • a Fiber of image



46
47
48
49
50
51
52
53
54
55
56
57
# File 'lib/images/item/with_image_item_request_builder.rb', line 46

def get(request_configuration=nil)
    request_info = self.to_get_request_information(
        request_configuration
    )
    error_mapping = Hash.new
    error_mapping["400"] = lambda {|pn| Rixl::Models::Github_com_rixlhq_api_internal_errorsErrorResponse.create_from_discriminator_value(pn) }
    error_mapping["401"] = lambda {|pn| Rixl::Models::Github_com_rixlhq_api_internal_errorsErrorResponse.create_from_discriminator_value(pn) }
    error_mapping["403"] = lambda {|pn| Rixl::Models::Github_com_rixlhq_api_internal_errorsErrorResponse.create_from_discriminator_value(pn) }
    error_mapping["404"] = lambda {|pn| Rixl::Models::Github_com_rixlhq_api_internal_errorsErrorResponse.create_from_discriminator_value(pn) }
    error_mapping["500"] = lambda {|pn| Rixl::Models::Github_com_rixlhq_api_internal_errorsErrorResponse.create_from_discriminator_value(pn) }
    return @request_adapter.send_async(request_info, lambda {|pn| Rixl::Models::Image.create_from_discriminator_value(pn) }, error_mapping)
end

#to_delete_request_information(request_configuration = nil) ⇒ Object

delete an image by marking it as deleted

Parameters:

  • request_configuration (defaults to: nil)

    Configuration for the request such as headers, query parameters, and middleware options.

Returns:

  • a request_information



63
64
65
66
67
68
69
70
71
72
73
74
# File 'lib/images/item/with_image_item_request_builder.rb', line 63

def to_delete_request_information(request_configuration=nil)
    request_info = MicrosoftKiotaAbstractions::RequestInformation.new()
    unless request_configuration.nil?
        request_info.add_headers_from_raw_object(request_configuration.headers)
        request_info.add_request_options(request_configuration.options)
    end
    request_info.url_template = @url_template
    request_info.path_parameters = @path_parameters
    request_info.http_method = :DELETE
    request_info.headers.try_add('Accept', 'application/json')
    return request_info
end

#to_get_request_information(request_configuration = nil) ⇒ Object

Retrieve an image by its ID for a specific project.

Parameters:

  • request_configuration (defaults to: nil)

    Configuration for the request such as headers, query parameters, and middleware options.

Returns:

  • a request_information



80
81
82
83
84
85
86
87
88
89
90
91
# File 'lib/images/item/with_image_item_request_builder.rb', line 80

def to_get_request_information(request_configuration=nil)
    request_info = MicrosoftKiotaAbstractions::RequestInformation.new()
    unless request_configuration.nil?
        request_info.add_headers_from_raw_object(request_configuration.headers)
        request_info.add_request_options(request_configuration.options)
    end
    request_info.url_template = @url_template
    request_info.path_parameters = @path_parameters
    request_info.http_method = :GET
    request_info.headers.try_add('Accept', 'application/json')
    return request_info
end

#with_url(raw_url) ⇒ Object

Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.

Parameters:

  • raw_url

    The raw URL to use for the request builder.

Returns:

  • a with_image_item_request_builder

Raises:

  • (StandardError)


97
98
99
100
# File 'lib/images/item/with_image_item_request_builder.rb', line 97

def with_url(raw_url)
    raise StandardError, 'raw_url cannot be null' if raw_url.nil?
    return WithImageItemRequestBuilder.new(raw_url, @request_adapter)
end