Class: Rixl::Models::Github_com_rixlhq_api_internal_errorsErrorResponse

Inherits:
MicrosoftKiotaAbstractions::ApiError
  • Object
show all
Includes:
MicrosoftKiotaAbstractions::AdditionalDataHolder, MicrosoftKiotaAbstractions::Parsable
Defined in:
lib/models/github_com_rixlhq_api_internal_errors_error_response.rb

Overview

Standard error response returned by the API

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initializeObject

Instantiates a new Github_com_rixlhq_api_internal_errorsErrorResponse and sets the default values.



57
58
59
60
# File 'lib/models/github_com_rixlhq_api_internal_errors_error_response.rb', line 57

def initialize()
    super
    @additional_data = Hash.new
end

Class Method Details

.create_from_discriminator_value(parse_node) ⇒ Object

Creates a new instance of the appropriate class based on discriminator value

Parameters:

  • parse_node

    The parse node to use to read the discriminator value and create the object

Returns:

  • a github_com_rixlhq_api_internal_errors_error_response

Raises:

  • (StandardError)


66
67
68
69
# File 'lib/models/github_com_rixlhq_api_internal_errors_error_response.rb', line 66

def self.create_from_discriminator_value(parse_node)
    raise StandardError, 'parse_node cannot be null' if parse_node.nil?
    return Github_com_rixlhq_api_internal_errorsErrorResponse.new
end

Instance Method Details

#additional_dataObject

Gets the AdditionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.

Returns:

  • a i_dictionary



27
28
29
# File 'lib/models/github_com_rixlhq_api_internal_errors_error_response.rb', line 27

def additional_data
    return @additional_data
end

#additional_data=(value) ⇒ Object

Sets the AdditionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.

Parameters:

  • value

    Value to set for the AdditionalData property.

Returns:

  • a void



35
36
37
# File 'lib/models/github_com_rixlhq_api_internal_errors_error_response.rb', line 35

def additional_data=(value)
    @additional_data = value
end

#codeObject

Gets the code property value. HTTP status code

Returns:

  • a integer



42
43
44
# File 'lib/models/github_com_rixlhq_api_internal_errors_error_response.rb', line 42

def code
    return @code
end

#code=(value) ⇒ Object

Sets the code property value. HTTP status code

Parameters:

  • value

    Value to set for the code property.

Returns:

  • a void



50
51
52
# File 'lib/models/github_com_rixlhq_api_internal_errors_error_response.rb', line 50

def code=(value)
    @code = value
end

#detailsObject

Gets the details property value. Optional details about the error

Returns:

  • a string



74
75
76
# File 'lib/models/github_com_rixlhq_api_internal_errors_error_response.rb', line 74

def details
    return @details
end

#details=(value) ⇒ Object

Sets the details property value. Optional details about the error

Parameters:

  • value

    Value to set for the details property.

Returns:

  • a void



82
83
84
# File 'lib/models/github_com_rixlhq_api_internal_errors_error_response.rb', line 82

def details=(value)
    @details = value
end

#errorObject

Gets the error property value. Error message describing what went wrong

Returns:

  • a string



89
90
91
# File 'lib/models/github_com_rixlhq_api_internal_errors_error_response.rb', line 89

def error
    return @error
end

#error=(value) ⇒ Object

Sets the error property value. Error message describing what went wrong

Parameters:

  • value

    Value to set for the error property.

Returns:

  • a void



97
98
99
# File 'lib/models/github_com_rixlhq_api_internal_errors_error_response.rb', line 97

def error=(value)
    @error = value
end

#get_field_deserializersObject

The deserialization information for the current model

Returns:

  • a i_dictionary



104
105
106
107
108
109
110
# File 'lib/models/github_com_rixlhq_api_internal_errors_error_response.rb', line 104

def get_field_deserializers()
    return super.merge({
        "code" => lambda {|n| @code = n.get_number_value() },
        "details" => lambda {|n| @details = n.get_string_value() },
        "error" => lambda {|n| @error = n.get_string_value() },
    })
end

#serialize(writer) ⇒ Object

Serializes information the current object

Parameters:

  • writer

    Serialization writer to use to serialize this model

Returns:

  • a void

Raises:

  • (StandardError)


116
117
118
119
120
121
122
123
# File 'lib/models/github_com_rixlhq_api_internal_errors_error_response.rb', line 116

def serialize(writer)
    raise StandardError, 'writer cannot be null' if writer.nil?
    super
    writer.write_number_value("code", @code)
    writer.write_string_value("details", @details)
    writer.write_string_value("error", @error)
    writer.write_additional_data(@additional_data)
end