Class: Rixl::Models::Github_com_rixlhq_api_internal_videos_handler_uploadInitResponse
- Inherits:
-
Object
- Object
- Rixl::Models::Github_com_rixlhq_api_internal_videos_handler_uploadInitResponse
- Includes:
- MicrosoftKiotaAbstractions::AdditionalDataHolder, MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/models/github_com_rixlhq_api_internal_videos_handler_upload_init_response.rb
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#additional_data ⇒ Object
Gets the AdditionalData property value.
-
#additional_data=(value) ⇒ Object
Sets the AdditionalData property value.
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#initialize ⇒ Object
constructor
Instantiates a new Github_com_rixlhq_api_internal_videos_handler_uploadInitResponse and sets the default values.
-
#poster_id ⇒ Object
Gets the poster_id property value.
-
#poster_id=(value) ⇒ Object
Sets the poster_id property value.
-
#poster_presigned_url ⇒ Object
Gets the poster_presigned_url property value.
-
#poster_presigned_url=(value) ⇒ Object
Sets the poster_presigned_url property value.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
-
#upload_expires ⇒ Object
Gets the upload_expires property value.
-
#upload_expires=(value) ⇒ Object
Sets the upload_expires property value.
-
#video_id ⇒ Object
Gets the video_id property value.
-
#video_id=(value) ⇒ Object
Sets the video_id property value.
-
#video_presigned_url ⇒ Object
Gets the video_presigned_url property value.
-
#video_presigned_url=(value) ⇒ Object
Sets the video_presigned_url property value.
Constructor Details
#initialize ⇒ Object
Instantiates a new Github_com_rixlhq_api_internal_videos_handler_uploadInitResponse and sets the default values.
46 47 48 |
# File 'lib/models/github_com_rixlhq_api_internal_videos_handler_upload_init_response.rb', line 46 def initialize() @additional_data = Hash.new end |
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
54 55 56 57 |
# File 'lib/models/github_com_rixlhq_api_internal_videos_handler_upload_init_response.rb', line 54 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return Github_com_rixlhq_api_internal_videos_handler_uploadInitResponse.new end |
Instance Method Details
#additional_data ⇒ Object
Gets the AdditionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
31 32 33 |
# File 'lib/models/github_com_rixlhq_api_internal_videos_handler_upload_init_response.rb', line 31 def additional_data return @additional_data end |
#additional_data=(value) ⇒ Object
Sets the AdditionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
39 40 41 |
# File 'lib/models/github_com_rixlhq_api_internal_videos_handler_upload_init_response.rb', line 39 def additional_data=(value) @additional_data = value end |
#get_field_deserializers ⇒ Object
The deserialization information for the current model
62 63 64 65 66 67 68 69 70 |
# File 'lib/models/github_com_rixlhq_api_internal_videos_handler_upload_init_response.rb', line 62 def get_field_deserializers() return { "poster_id" => lambda {|n| @poster_id = n.get_string_value() }, "poster_presigned_url" => lambda {|n| @poster_presigned_url = n.get_string_value() }, "upload_expires" => lambda {|n| @upload_expires = n.get_number_value() }, "video_id" => lambda {|n| @video_id = n.get_string_value() }, "video_presigned_url" => lambda {|n| @video_presigned_url = n.get_string_value() }, } end |
#poster_id ⇒ Object
Gets the poster_id property value. The poster_id property
75 76 77 |
# File 'lib/models/github_com_rixlhq_api_internal_videos_handler_upload_init_response.rb', line 75 def poster_id return @poster_id end |
#poster_id=(value) ⇒ Object
Sets the poster_id property value. The poster_id property
83 84 85 |
# File 'lib/models/github_com_rixlhq_api_internal_videos_handler_upload_init_response.rb', line 83 def poster_id=(value) @poster_id = value end |
#poster_presigned_url ⇒ Object
Gets the poster_presigned_url property value. The poster_presigned_url property
90 91 92 |
# File 'lib/models/github_com_rixlhq_api_internal_videos_handler_upload_init_response.rb', line 90 def poster_presigned_url return @poster_presigned_url end |
#poster_presigned_url=(value) ⇒ Object
Sets the poster_presigned_url property value. The poster_presigned_url property
98 99 100 |
# File 'lib/models/github_com_rixlhq_api_internal_videos_handler_upload_init_response.rb', line 98 def poster_presigned_url=(value) @poster_presigned_url = value end |
#serialize(writer) ⇒ Object
Serializes information the current object
106 107 108 109 110 111 112 113 114 |
# File 'lib/models/github_com_rixlhq_api_internal_videos_handler_upload_init_response.rb', line 106 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? writer.write_string_value("poster_id", @poster_id) writer.write_string_value("poster_presigned_url", @poster_presigned_url) writer.write_number_value("upload_expires", @upload_expires) writer.write_string_value("video_id", @video_id) writer.write_string_value("video_presigned_url", @video_presigned_url) writer.write_additional_data(@additional_data) end |
#upload_expires ⇒ Object
Gets the upload_expires property value. The upload_expires property
119 120 121 |
# File 'lib/models/github_com_rixlhq_api_internal_videos_handler_upload_init_response.rb', line 119 def upload_expires return @upload_expires end |
#upload_expires=(value) ⇒ Object
Sets the upload_expires property value. The upload_expires property
127 128 129 |
# File 'lib/models/github_com_rixlhq_api_internal_videos_handler_upload_init_response.rb', line 127 def upload_expires=(value) @upload_expires = value end |
#video_id ⇒ Object
Gets the video_id property value. The video_id property
134 135 136 |
# File 'lib/models/github_com_rixlhq_api_internal_videos_handler_upload_init_response.rb', line 134 def video_id return @video_id end |
#video_id=(value) ⇒ Object
Sets the video_id property value. The video_id property
142 143 144 |
# File 'lib/models/github_com_rixlhq_api_internal_videos_handler_upload_init_response.rb', line 142 def video_id=(value) @video_id = value end |
#video_presigned_url ⇒ Object
Gets the video_presigned_url property value. The video_presigned_url property
149 150 151 |
# File 'lib/models/github_com_rixlhq_api_internal_videos_handler_upload_init_response.rb', line 149 def video_presigned_url return @video_presigned_url end |
#video_presigned_url=(value) ⇒ Object
Sets the video_presigned_url property value. The video_presigned_url property
157 158 159 |
# File 'lib/models/github_com_rixlhq_api_internal_videos_handler_upload_init_response.rb', line 157 def video_presigned_url=(value) @video_presigned_url = value end |