Class: Rixl::Models::Internal_images_handlerCompleteRequest
- Inherits:
-
Object
- Object
- Rixl::Models::Internal_images_handlerCompleteRequest
- Includes:
- MicrosoftKiotaAbstractions::AdditionalDataHolder, MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/models/internal_images_handler_complete_request.rb
Overview
Upload completion request
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#additional_data ⇒ Object
Gets the AdditionalData property value.
-
#additional_data=(value) ⇒ Object
Sets the AdditionalData property value.
-
#attached_to_video ⇒ Object
Gets the attached_to_video property value.
-
#attached_to_video=(value) ⇒ Object
Sets the attached_to_video property value.
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#image_id ⇒ Object
Gets the image_id property value.
-
#image_id=(value) ⇒ Object
Sets the image_id property value.
-
#initialize ⇒ Object
constructor
Instantiates a new Internal_images_handlerCompleteRequest and sets the default values.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
Constructor Details
#initialize ⇒ Object
Instantiates a new Internal_images_handlerCompleteRequest and sets the default values.
54 55 56 |
# File 'lib/models/internal_images_handler_complete_request.rb', line 54 def initialize() @additional_data = Hash.new end |
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
62 63 64 65 |
# File 'lib/models/internal_images_handler_complete_request.rb', line 62 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return Internal_images_handlerCompleteRequest.new end |
Instance Method Details
#additional_data ⇒ Object
Gets the AdditionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
24 25 26 |
# File 'lib/models/internal_images_handler_complete_request.rb', line 24 def additional_data return @additional_data end |
#additional_data=(value) ⇒ Object
Sets the AdditionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
32 33 34 |
# File 'lib/models/internal_images_handler_complete_request.rb', line 32 def additional_data=(value) @additional_data = value end |
#attached_to_video ⇒ Object
Gets the attached_to_video property value. The attached_to_video property
39 40 41 |
# File 'lib/models/internal_images_handler_complete_request.rb', line 39 def attached_to_video return @attached_to_video end |
#attached_to_video=(value) ⇒ Object
Sets the attached_to_video property value. The attached_to_video property
47 48 49 |
# File 'lib/models/internal_images_handler_complete_request.rb', line 47 def attached_to_video=(value) @attached_to_video = value end |
#get_field_deserializers ⇒ Object
The deserialization information for the current model
70 71 72 73 74 75 |
# File 'lib/models/internal_images_handler_complete_request.rb', line 70 def get_field_deserializers() return { "attached_to_video" => lambda {|n| @attached_to_video = n.get_boolean_value() }, "image_id" => lambda {|n| @image_id = n.get_string_value() }, } end |
#image_id ⇒ Object
Gets the image_id property value. The image_id property
80 81 82 |
# File 'lib/models/internal_images_handler_complete_request.rb', line 80 def image_id return @image_id end |
#image_id=(value) ⇒ Object
Sets the image_id property value. The image_id property
88 89 90 |
# File 'lib/models/internal_images_handler_complete_request.rb', line 88 def image_id=(value) @image_id = value end |
#serialize(writer) ⇒ Object
Serializes information the current object
96 97 98 99 100 101 |
# File 'lib/models/internal_images_handler_complete_request.rb', line 96 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? writer.write_boolean_value("attached_to_video", @attached_to_video) writer.write_string_value("image_id", @image_id) writer.write_additional_data(@additional_data) end |