Class: Rixl::Models::SubtitleDelete
- Inherits:
-
Object
- Object
- Rixl::Models::SubtitleDelete
- Includes:
- MicrosoftKiotaAbstractions::AdditionalDataHolder, MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/models/subtitle_delete.rb
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#additional_data ⇒ Object
Gets the AdditionalData property value.
-
#additional_data=(value) ⇒ Object
Sets the AdditionalData property value.
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#initialize ⇒ Object
constructor
Instantiates a new SubtitleDelete and sets the default values.
-
#message ⇒ Object
Gets the message property value.
-
#message=(value) ⇒ Object
Sets the message property value.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
-
#status ⇒ Object
Gets the status property value.
-
#status=(value) ⇒ Object
Sets the status property value.
Constructor Details
#initialize ⇒ Object
Instantiates a new SubtitleDelete and sets the default values.
37 38 39 |
# File 'lib/models/subtitle_delete.rb', line 37 def initialize() @additional_data = Hash.new end |
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
45 46 47 48 |
# File 'lib/models/subtitle_delete.rb', line 45 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return SubtitleDelete.new end |
Instance Method Details
#additional_data ⇒ Object
Gets the AdditionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
22 23 24 |
# File 'lib/models/subtitle_delete.rb', line 22 def additional_data return @additional_data end |
#additional_data=(value) ⇒ Object
Sets the AdditionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
30 31 32 |
# File 'lib/models/subtitle_delete.rb', line 30 def additional_data=(value) @additional_data = value end |
#get_field_deserializers ⇒ Object
The deserialization information for the current model
53 54 55 56 57 58 |
# File 'lib/models/subtitle_delete.rb', line 53 def get_field_deserializers() return { "message" => lambda {|n| @message = n.get_string_value() }, "status" => lambda {|n| @status = n.get_string_value() }, } end |
#message ⇒ Object
Gets the message property value. The message property
63 64 65 |
# File 'lib/models/subtitle_delete.rb', line 63 def return @message end |
#message=(value) ⇒ Object
Sets the message property value. The message property
71 72 73 |
# File 'lib/models/subtitle_delete.rb', line 71 def (value) @message = value end |
#serialize(writer) ⇒ Object
Serializes information the current object
79 80 81 82 83 84 |
# File 'lib/models/subtitle_delete.rb', line 79 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? writer.write_string_value("message", @message) writer.write_string_value("status", @status) writer.write_additional_data(@additional_data) end |
#status ⇒ Object
Gets the status property value. The status property
89 90 91 |
# File 'lib/models/subtitle_delete.rb', line 89 def status return @status end |
#status=(value) ⇒ Object
Sets the status property value. The status property
97 98 99 |
# File 'lib/models/subtitle_delete.rb', line 97 def status=(value) @status = value end |