Class: Rixl::Models::UpdateChaptersRequest

Inherits:
Object
  • Object
show all
Includes:
MicrosoftKiotaAbstractions::AdditionalDataHolder, MicrosoftKiotaAbstractions::Parsable
Defined in:
lib/models/update_chapters_request.rb

Overview

Chapters array

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initializeObject

Instantiates a new UpdateChaptersRequest and sets the default values.



51
52
53
# File 'lib/models/update_chapters_request.rb', line 51

def initialize()
    @additional_data = Hash.new
end

Class Method Details

.create_from_discriminator_value(parse_node) ⇒ Object

Creates a new instance of the appropriate class based on discriminator value

Parameters:

  • parse_node

    The parse node to use to read the discriminator value and create the object

Returns:

  • a update_chapters_request

Raises:

  • (StandardError)


59
60
61
62
# File 'lib/models/update_chapters_request.rb', line 59

def self.create_from_discriminator_value(parse_node)
    raise StandardError, 'parse_node cannot be null' if parse_node.nil?
    return UpdateChaptersRequest.new
end

Instance Method Details

#additional_dataObject

Gets the AdditionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.

Returns:

  • a i_dictionary



21
22
23
# File 'lib/models/update_chapters_request.rb', line 21

def additional_data
    return @additional_data
end

#additional_data=(value) ⇒ Object

Sets the AdditionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.

Parameters:

  • value

    Value to set for the AdditionalData property.

Returns:

  • a void



29
30
31
# File 'lib/models/update_chapters_request.rb', line 29

def additional_data=(value)
    @additional_data = value
end

#chaptersObject

Gets the chapters property value. The chapters property

Returns:

  • a github_com_rixlhq_api_internal_videos_types_chapter_input



36
37
38
# File 'lib/models/update_chapters_request.rb', line 36

def chapters
    return @chapters
end

#chapters=(value) ⇒ Object

Sets the chapters property value. The chapters property

Parameters:

  • value

    Value to set for the chapters property.

Returns:

  • a void



44
45
46
# File 'lib/models/update_chapters_request.rb', line 44

def chapters=(value)
    @chapters = value
end

#get_field_deserializersObject

The deserialization information for the current model

Returns:

  • a i_dictionary



67
68
69
70
71
# File 'lib/models/update_chapters_request.rb', line 67

def get_field_deserializers()
    return {
        "chapters" => lambda {|n| @chapters = n.get_collection_of_object_values(lambda {|pn| Rixl::Models::Github_com_rixlhq_api_internal_videos_typesChapterInput.create_from_discriminator_value(pn) }) },
    }
end

#serialize(writer) ⇒ Object

Serializes information the current object

Parameters:

  • writer

    Serialization writer to use to serialize this model

Returns:

  • a void

Raises:

  • (StandardError)


77
78
79
80
81
# File 'lib/models/update_chapters_request.rb', line 77

def serialize(writer)
    raise StandardError, 'writer cannot be null' if writer.nil?
    writer.write_collection_of_object_values("chapters", @chapters)
    writer.write_additional_data(@additional_data)
end