Class: Rixl::Models::UpdateChaptersResponse

Inherits:
Object
  • Object
show all
Includes:
MicrosoftKiotaAbstractions::AdditionalDataHolder, MicrosoftKiotaAbstractions::Parsable
Defined in:
lib/models/update_chapters_response.rb

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initializeObject

Instantiates a new UpdateChaptersResponse and sets the default values.



52
53
54
# File 'lib/models/update_chapters_response.rb', line 52

def initialize()
    @additional_data = Hash.new
end

Class Method Details

.create_from_discriminator_value(parse_node) ⇒ Object

Creates a new instance of the appropriate class based on discriminator value

Parameters:

  • parse_node

    The parse node to use to read the discriminator value and create the object

Returns:

  • a update_chapters_response

Raises:

  • (StandardError)


60
61
62
63
# File 'lib/models/update_chapters_response.rb', line 60

def self.create_from_discriminator_value(parse_node)
    raise StandardError, 'parse_node cannot be null' if parse_node.nil?
    return UpdateChaptersResponse.new
end

Instance Method Details

#additional_dataObject

Gets the AdditionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.

Returns:

  • a i_dictionary



22
23
24
# File 'lib/models/update_chapters_response.rb', line 22

def additional_data
    return @additional_data
end

#additional_data=(value) ⇒ Object

Sets the AdditionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.

Parameters:

  • value

    Value to set for the AdditionalData property.

Returns:

  • a void



30
31
32
# File 'lib/models/update_chapters_response.rb', line 30

def additional_data=(value)
    @additional_data = value
end

#chaptersObject

Gets the chapters property value. The chapters property

Returns:

  • a chapter



37
38
39
# File 'lib/models/update_chapters_response.rb', line 37

def chapters
    return @chapters
end

#chapters=(value) ⇒ Object

Sets the chapters property value. The chapters property

Parameters:

  • value

    Value to set for the chapters property.

Returns:

  • a void



45
46
47
# File 'lib/models/update_chapters_response.rb', line 45

def chapters=(value)
    @chapters = value
end

#get_field_deserializersObject

The deserialization information for the current model

Returns:

  • a i_dictionary



68
69
70
71
72
73
# File 'lib/models/update_chapters_response.rb', line 68

def get_field_deserializers()
    return {
        "chapters" => lambda {|n| @chapters = n.get_collection_of_object_values(lambda {|pn| Rixl::Models::Chapter.create_from_discriminator_value(pn) }) },
        "video_id" => lambda {|n| @video_id = n.get_string_value() },
    }
end

#serialize(writer) ⇒ Object

Serializes information the current object

Parameters:

  • writer

    Serialization writer to use to serialize this model

Returns:

  • a void

Raises:

  • (StandardError)


79
80
81
82
83
84
# File 'lib/models/update_chapters_response.rb', line 79

def serialize(writer)
    raise StandardError, 'writer cannot be null' if writer.nil?
    writer.write_collection_of_object_values("chapters", @chapters)
    writer.write_string_value("video_id", @video_id)
    writer.write_additional_data(@additional_data)
end

#video_idObject

Gets the video_id property value. The video_id property

Returns:

  • a string



89
90
91
# File 'lib/models/update_chapters_response.rb', line 89

def video_id
    return @video_id
end

#video_id=(value) ⇒ Object

Sets the video_id property value. The video_id property

Parameters:

  • value

    Value to set for the video_id property.

Returns:

  • a void



97
98
99
# File 'lib/models/update_chapters_response.rb', line 97

def video_id=(value)
    @video_id = value
end