Class: Rixl::Models::VideoUploadInitRequest
- Inherits:
-
Object
- Object
- Rixl::Models::VideoUploadInitRequest
- Includes:
- MicrosoftKiotaAbstractions::AdditionalDataHolder, MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/models/video_upload_init_request.rb
Overview
Video upload initialization request
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#additional_data ⇒ Object
Gets the AdditionalData property value.
-
#additional_data=(value) ⇒ Object
Sets the AdditionalData property value.
-
#file_name ⇒ Object
Gets the file_name property value.
-
#file_name=(value) ⇒ Object
Sets the file_name property value.
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#image_format ⇒ Object
Gets the image_format property value.
-
#image_format=(value) ⇒ Object
Sets the image_format property value.
-
#initialize ⇒ Object
constructor
Instantiates a new VideoUploadInitRequest and sets the default values.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
-
#video_quality ⇒ Object
Gets the video_quality property value.
-
#video_quality=(value) ⇒ Object
Sets the video_quality property value.
Constructor Details
#initialize ⇒ Object
Instantiates a new VideoUploadInitRequest and sets the default values.
42 43 44 |
# File 'lib/models/video_upload_init_request.rb', line 42 def initialize() @additional_data = Hash.new end |
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
50 51 52 53 |
# File 'lib/models/video_upload_init_request.rb', line 50 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return VideoUploadInitRequest.new end |
Instance Method Details
#additional_data ⇒ Object
Gets the AdditionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
27 28 29 |
# File 'lib/models/video_upload_init_request.rb', line 27 def additional_data return @additional_data end |
#additional_data=(value) ⇒ Object
Sets the AdditionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
35 36 37 |
# File 'lib/models/video_upload_init_request.rb', line 35 def additional_data=(value) @additional_data = value end |
#file_name ⇒ Object
Gets the file_name property value. The file_name property
58 59 60 |
# File 'lib/models/video_upload_init_request.rb', line 58 def file_name return @file_name end |
#file_name=(value) ⇒ Object
Sets the file_name property value. The file_name property
66 67 68 |
# File 'lib/models/video_upload_init_request.rb', line 66 def file_name=(value) @file_name = value end |
#get_field_deserializers ⇒ Object
The deserialization information for the current model
73 74 75 76 77 78 79 |
# File 'lib/models/video_upload_init_request.rb', line 73 def get_field_deserializers() return { "file_name" => lambda {|n| @file_name = n.get_string_value() }, "image_format" => lambda {|n| @image_format = n.get_string_value() }, "video_quality" => lambda {|n| @video_quality = n.get_enum_value(Rixl::Models::Github_com_rixlhq_api_db_sqlcVideoQuality) }, } end |
#image_format ⇒ Object
Gets the image_format property value. The image_format property
84 85 86 |
# File 'lib/models/video_upload_init_request.rb', line 84 def image_format return @image_format end |
#image_format=(value) ⇒ Object
Sets the image_format property value. The image_format property
92 93 94 |
# File 'lib/models/video_upload_init_request.rb', line 92 def image_format=(value) @image_format = value end |
#serialize(writer) ⇒ Object
Serializes information the current object
100 101 102 103 104 105 106 |
# File 'lib/models/video_upload_init_request.rb', line 100 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? writer.write_string_value("file_name", @file_name) writer.write_string_value("image_format", @image_format) writer.write_enum_value("video_quality", @video_quality) writer.write_additional_data(@additional_data) end |
#video_quality ⇒ Object
Gets the video_quality property value. The video_quality property
111 112 113 |
# File 'lib/models/video_upload_init_request.rb', line 111 def video_quality return @video_quality end |
#video_quality=(value) ⇒ Object
Sets the video_quality property value. The video_quality property
119 120 121 |
# File 'lib/models/video_upload_init_request.rb', line 119 def video_quality=(value) @video_quality = value end |