Class: Rixl::Videos::Item::Chapters::ChaptersRequestBuilder

Inherits:
MicrosoftKiotaAbstractions::BaseRequestBuilder
  • Object
show all
Defined in:
lib/videos/item/chapters/chapters_request_builder.rb

Overview

Builds and executes requests for operations under videosvideoIdchapters

Instance Method Summary collapse

Constructor Details

#initialize(path_parameters, request_adapter) ⇒ Object

Instantiates a new ChaptersRequestBuilder and sets the default values.

Parameters:

  • path_parameters

    Path parameters for the request

  • request_adapter

    The request adapter to use to execute the requests.



24
25
26
# File 'lib/videos/item/chapters/chapters_request_builder.rb', line 24

def initialize(path_parameters, request_adapter)
    super(path_parameters, request_adapter, "{+baseurl}/videos/{videoId}/chapters")
end

Instance Method Details

#delete(request_configuration = nil) ⇒ Object

Remove all chapters from a video using API key authentication

Parameters:

  • request_configuration (defaults to: nil)

    Configuration for the request such as headers, query parameters, and middleware options.

Returns:

  • a Fiber of update_chapters_response



32
33
34
35
36
37
38
39
40
41
42
# File 'lib/videos/item/chapters/chapters_request_builder.rb', line 32

def delete(request_configuration=nil)
    request_info = self.to_delete_request_information(
        request_configuration
    )
    error_mapping = Hash.new
    error_mapping["401"] = lambda {|pn| Rixl::Models::Github_com_rixlhq_api_internal_errorsErrorResponse.create_from_discriminator_value(pn) }
    error_mapping["403"] = lambda {|pn| Rixl::Models::Github_com_rixlhq_api_internal_errorsErrorResponse.create_from_discriminator_value(pn) }
    error_mapping["404"] = lambda {|pn| Rixl::Models::Github_com_rixlhq_api_internal_errorsErrorResponse.create_from_discriminator_value(pn) }
    error_mapping["500"] = lambda {|pn| Rixl::Models::Github_com_rixlhq_api_internal_errorsErrorResponse.create_from_discriminator_value(pn) }
    return @request_adapter.send_async(request_info, lambda {|pn| Rixl::Models::UpdateChaptersResponse.create_from_discriminator_value(pn) }, error_mapping)
end

#put(body, request_configuration = nil) ⇒ Object

Replace all chapters for a video (atomic PUT operation) using API key authentication

Parameters:

  • body

    Chapters array

  • request_configuration (defaults to: nil)

    Configuration for the request such as headers, query parameters, and middleware options.

Returns:

  • a Fiber of update_chapters_response

Raises:

  • (StandardError)


49
50
51
52
53
54
55
56
57
58
59
60
61
# File 'lib/videos/item/chapters/chapters_request_builder.rb', line 49

def put(body, request_configuration=nil)
    raise StandardError, 'body cannot be null' if body.nil?
    request_info = self.to_put_request_information(
        body, request_configuration
    )
    error_mapping = Hash.new
    error_mapping["400"] = lambda {|pn| Rixl::Models::Github_com_rixlhq_api_internal_errorsErrorResponse.create_from_discriminator_value(pn) }
    error_mapping["401"] = lambda {|pn| Rixl::Models::Github_com_rixlhq_api_internal_errorsErrorResponse.create_from_discriminator_value(pn) }
    error_mapping["403"] = lambda {|pn| Rixl::Models::Github_com_rixlhq_api_internal_errorsErrorResponse.create_from_discriminator_value(pn) }
    error_mapping["404"] = lambda {|pn| Rixl::Models::Github_com_rixlhq_api_internal_errorsErrorResponse.create_from_discriminator_value(pn) }
    error_mapping["500"] = lambda {|pn| Rixl::Models::Github_com_rixlhq_api_internal_errorsErrorResponse.create_from_discriminator_value(pn) }
    return @request_adapter.send_async(request_info, lambda {|pn| Rixl::Models::UpdateChaptersResponse.create_from_discriminator_value(pn) }, error_mapping)
end

#to_delete_request_information(request_configuration = nil) ⇒ Object

Remove all chapters from a video using API key authentication

Parameters:

  • request_configuration (defaults to: nil)

    Configuration for the request such as headers, query parameters, and middleware options.

Returns:

  • a request_information



67
68
69
70
71
72
73
74
75
76
77
78
# File 'lib/videos/item/chapters/chapters_request_builder.rb', line 67

def to_delete_request_information(request_configuration=nil)
    request_info = MicrosoftKiotaAbstractions::RequestInformation.new()
    unless request_configuration.nil?
        request_info.add_headers_from_raw_object(request_configuration.headers)
        request_info.add_request_options(request_configuration.options)
    end
    request_info.url_template = @url_template
    request_info.path_parameters = @path_parameters
    request_info.http_method = :DELETE
    request_info.headers.try_add('Accept', 'application/json')
    return request_info
end

#to_put_request_information(body, request_configuration = nil) ⇒ Object

Replace all chapters for a video (atomic PUT operation) using API key authentication

Parameters:

  • body

    Chapters array

  • request_configuration (defaults to: nil)

    Configuration for the request such as headers, query parameters, and middleware options.

Returns:

  • a request_information

Raises:

  • (StandardError)


85
86
87
88
89
90
91
92
93
94
95
96
97
98
# File 'lib/videos/item/chapters/chapters_request_builder.rb', line 85

def to_put_request_information(body, request_configuration=nil)
    raise StandardError, 'body cannot be null' if body.nil?
    request_info = MicrosoftKiotaAbstractions::RequestInformation.new()
    unless request_configuration.nil?
        request_info.add_headers_from_raw_object(request_configuration.headers)
        request_info.add_request_options(request_configuration.options)
    end
    request_info.set_content_from_parsable(@request_adapter, 'application/json', body)
    request_info.url_template = @url_template
    request_info.path_parameters = @path_parameters
    request_info.http_method = :PUT
    request_info.headers.try_add('Accept', 'application/json')
    return request_info
end

#with_url(raw_url) ⇒ Object

Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.

Parameters:

  • raw_url

    The raw URL to use for the request builder.

Returns:

  • a chapters_request_builder

Raises:

  • (StandardError)


104
105
106
107
# File 'lib/videos/item/chapters/chapters_request_builder.rb', line 104

def with_url(raw_url)
    raise StandardError, 'raw_url cannot be null' if raw_url.nil?
    return ChaptersRequestBuilder.new(raw_url, @request_adapter)
end