Class: Rixl::Videos::Item::Delete::DeleteRequestBuilder
- Inherits:
-
MicrosoftKiotaAbstractions::BaseRequestBuilder
- Object
- MicrosoftKiotaAbstractions::BaseRequestBuilder
- Rixl::Videos::Item::Delete::DeleteRequestBuilder
- Defined in:
- lib/videos/item/delete/delete_request_builder.rb
Overview
Builds and executes requests for operations under videosvideoIddelete
Instance Method Summary collapse
-
#delete(request_configuration = nil) ⇒ Object
Delete a video by its ID within a project.
-
#initialize(path_parameters, request_adapter) ⇒ Object
constructor
Instantiates a new DeleteRequestBuilder and sets the default values.
-
#to_delete_request_information(request_configuration = nil) ⇒ Object
Delete a video by its ID within a project.
-
#with_url(raw_url) ⇒ Object
Returns a request builder with the provided arbitrary URL.
Constructor Details
#initialize(path_parameters, request_adapter) ⇒ Object
Instantiates a new DeleteRequestBuilder and sets the default values.
22 23 24 |
# File 'lib/videos/item/delete/delete_request_builder.rb', line 22 def initialize(path_parameters, request_adapter) super(path_parameters, request_adapter, "{+baseurl}/videos/{videoId}/delete") end |
Instance Method Details
#delete(request_configuration = nil) ⇒ Object
Delete a video by its ID within a project
30 31 32 33 34 35 36 37 38 39 40 41 |
# File 'lib/videos/item/delete/delete_request_builder.rb', line 30 def delete(request_configuration=nil) request_info = self.to_delete_request_information( request_configuration ) error_mapping = Hash.new error_mapping["400"] = lambda {|pn| Rixl::Models::Github_com_rixlhq_api_internal_errorsErrorResponse.create_from_discriminator_value(pn) } error_mapping["401"] = lambda {|pn| Rixl::Models::Github_com_rixlhq_api_internal_errorsErrorResponse.create_from_discriminator_value(pn) } error_mapping["403"] = lambda {|pn| Rixl::Models::Github_com_rixlhq_api_internal_errorsErrorResponse.create_from_discriminator_value(pn) } error_mapping["404"] = lambda {|pn| Rixl::Models::Github_com_rixlhq_api_internal_errorsErrorResponse.create_from_discriminator_value(pn) } error_mapping["500"] = lambda {|pn| Rixl::Models::Github_com_rixlhq_api_internal_errorsErrorResponse.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, nil, error_mapping) end |
#to_delete_request_information(request_configuration = nil) ⇒ Object
Delete a video by its ID within a project
47 48 49 50 51 52 53 54 55 56 57 58 |
# File 'lib/videos/item/delete/delete_request_builder.rb', line 47 def to_delete_request_information(request_configuration=nil) request_info = MicrosoftKiotaAbstractions::RequestInformation.new() unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.(request_configuration.) end request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :DELETE request_info.headers.try_add('Accept', 'application/json') return request_info end |
#with_url(raw_url) ⇒ Object
Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
64 65 66 67 |
# File 'lib/videos/item/delete/delete_request_builder.rb', line 64 def with_url(raw_url) raise StandardError, 'raw_url cannot be null' if raw_url.nil? return DeleteRequestBuilder.new(raw_url, @request_adapter) end |