Class: Rixl::Videos::Item::Thumbnail::ThumbnailRequestBuilder
- Inherits:
-
MicrosoftKiotaAbstractions::BaseRequestBuilder
- Object
- MicrosoftKiotaAbstractions::BaseRequestBuilder
- Rixl::Videos::Item::Thumbnail::ThumbnailRequestBuilder
- Defined in:
- lib/videos/item/thumbnail/thumbnail_request_builder.rb
Overview
Builds and executes requests for operations under videosvideoIdthumbnail
Instance Method Summary collapse
-
#initialize(path_parameters, request_adapter) ⇒ Object
constructor
Instantiates a new ThumbnailRequestBuilder and sets the default values.
-
#put(body, request_configuration = nil) ⇒ Object
Update the thumbnail image for an existing video using API key authentication.
-
#to_put_request_information(body, request_configuration = nil) ⇒ Object
Update the thumbnail image for an existing video using API key authentication.
-
#with_url(raw_url) ⇒ Object
Returns a request builder with the provided arbitrary URL.
Constructor Details
#initialize(path_parameters, request_adapter) ⇒ Object
Instantiates a new ThumbnailRequestBuilder and sets the default values.
23 24 25 |
# File 'lib/videos/item/thumbnail/thumbnail_request_builder.rb', line 23 def initialize(path_parameters, request_adapter) super(path_parameters, request_adapter, "{+baseurl}/videos/{videoId}/thumbnail") end |
Instance Method Details
#put(body, request_configuration = nil) ⇒ Object
Update the thumbnail image for an existing video using API key authentication
32 33 34 35 36 37 38 39 40 41 42 43 44 |
# File 'lib/videos/item/thumbnail/thumbnail_request_builder.rb', line 32 def put(body, request_configuration=nil) raise StandardError, 'body cannot be null' if body.nil? request_info = self.to_put_request_information( body, request_configuration ) error_mapping = Hash.new error_mapping["400"] = lambda {|pn| Rixl::Models::Github_com_rixlhq_api_internal_errorsErrorResponse.create_from_discriminator_value(pn) } error_mapping["401"] = lambda {|pn| Rixl::Models::Github_com_rixlhq_api_internal_errorsErrorResponse.create_from_discriminator_value(pn) } error_mapping["403"] = lambda {|pn| Rixl::Models::Github_com_rixlhq_api_internal_errorsErrorResponse.create_from_discriminator_value(pn) } error_mapping["404"] = lambda {|pn| Rixl::Models::Github_com_rixlhq_api_internal_errorsErrorResponse.create_from_discriminator_value(pn) } error_mapping["500"] = lambda {|pn| Rixl::Models::Github_com_rixlhq_api_internal_errorsErrorResponse.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, lambda {|pn| Rixl::Models::Video.create_from_discriminator_value(pn) }, error_mapping) end |
#to_put_request_information(body, request_configuration = nil) ⇒ Object
Update the thumbnail image for an existing video using API key authentication
51 52 53 54 55 56 57 58 59 60 61 62 63 64 |
# File 'lib/videos/item/thumbnail/thumbnail_request_builder.rb', line 51 def to_put_request_information(body, request_configuration=nil) raise StandardError, 'body cannot be null' if body.nil? request_info = MicrosoftKiotaAbstractions::RequestInformation.new() unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.(request_configuration.) end request_info.set_content_from_parsable(@request_adapter, 'multipart/form-data', body) request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :PUT request_info.headers.try_add('Accept', 'application/json') return request_info end |
#with_url(raw_url) ⇒ Object
Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
70 71 72 73 |
# File 'lib/videos/item/thumbnail/thumbnail_request_builder.rb', line 70 def with_url(raw_url) raise StandardError, 'raw_url cannot be null' if raw_url.nil? return ThumbnailRequestBuilder.new(raw_url, @request_adapter) end |