Class: Rixl::Videos::Item::WithVideoItemRequestBuilder
- Inherits:
-
MicrosoftKiotaAbstractions::BaseRequestBuilder
- Object
- MicrosoftKiotaAbstractions::BaseRequestBuilder
- Rixl::Videos::Item::WithVideoItemRequestBuilder
- Defined in:
- lib/videos/item/with_video_item_request_builder.rb
Overview
Builds and executes requests for operations under videosvideoId
Instance Method Summary collapse
-
#audio_tracks ⇒ Object
The audioTracks property.
-
#chapters ⇒ Object
The chapters property.
-
#delete_path ⇒ Object
The deletePath property.
-
#get(request_configuration = nil) ⇒ Object
Retrieve a video by its ID for a specific project.
-
#initialize(path_parameters, request_adapter) ⇒ Object
constructor
Instantiates a new WithVideoItemRequestBuilder and sets the default values.
-
#subtitles ⇒ Object
The subtitles property.
-
#thumbnail ⇒ Object
The thumbnail property.
-
#to_get_request_information(request_configuration = nil) ⇒ Object
Retrieve a video by its ID for a specific project.
-
#with_url(raw_url) ⇒ Object
Returns a request builder with the provided arbitrary URL.
Constructor Details
#initialize(path_parameters, request_adapter) ⇒ Object
Instantiates a new WithVideoItemRequestBuilder and sets the default values.
51 52 53 |
# File 'lib/videos/item/with_video_item_request_builder.rb', line 51 def initialize(path_parameters, request_adapter) super(path_parameters, request_adapter, "{+baseurl}/videos/{videoId}") end |
Instance Method Details
#audio_tracks ⇒ Object
The audioTracks property
22 23 24 |
# File 'lib/videos/item/with_video_item_request_builder.rb', line 22 def audio_tracks() return Rixl::Videos::Item::AudioTracks::AudioTracksRequestBuilder.new(@path_parameters, @request_adapter) end |
#chapters ⇒ Object
The chapters property
27 28 29 |
# File 'lib/videos/item/with_video_item_request_builder.rb', line 27 def chapters() return Rixl::Videos::Item::Chapters::ChaptersRequestBuilder.new(@path_parameters, @request_adapter) end |
#delete_path ⇒ Object
The deletePath property
32 33 34 |
# File 'lib/videos/item/with_video_item_request_builder.rb', line 32 def delete_path() return Rixl::Videos::Item::Delete::DeleteRequestBuilder.new(@path_parameters, @request_adapter) end |
#get(request_configuration = nil) ⇒ Object
Retrieve a video by its ID for a specific project.
59 60 61 62 63 64 65 66 67 68 69 70 |
# File 'lib/videos/item/with_video_item_request_builder.rb', line 59 def get(request_configuration=nil) request_info = self.to_get_request_information( request_configuration ) error_mapping = Hash.new error_mapping["400"] = lambda {|pn| Rixl::Models::Github_com_rixlhq_api_internal_errorsErrorResponse.create_from_discriminator_value(pn) } error_mapping["401"] = lambda {|pn| Rixl::Models::Github_com_rixlhq_api_internal_errorsErrorResponse.create_from_discriminator_value(pn) } error_mapping["403"] = lambda {|pn| Rixl::Models::Github_com_rixlhq_api_internal_errorsErrorResponse.create_from_discriminator_value(pn) } error_mapping["404"] = lambda {|pn| Rixl::Models::Github_com_rixlhq_api_internal_errorsErrorResponse.create_from_discriminator_value(pn) } error_mapping["500"] = lambda {|pn| Rixl::Models::Github_com_rixlhq_api_internal_errorsErrorResponse.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, lambda {|pn| Rixl::Models::Video.create_from_discriminator_value(pn) }, error_mapping) end |
#subtitles ⇒ Object
The subtitles property
37 38 39 |
# File 'lib/videos/item/with_video_item_request_builder.rb', line 37 def subtitles() return Rixl::Videos::Item::Subtitles::SubtitlesRequestBuilder.new(@path_parameters, @request_adapter) end |
#thumbnail ⇒ Object
The thumbnail property
42 43 44 |
# File 'lib/videos/item/with_video_item_request_builder.rb', line 42 def thumbnail() return Rixl::Videos::Item::Thumbnail::ThumbnailRequestBuilder.new(@path_parameters, @request_adapter) end |
#to_get_request_information(request_configuration = nil) ⇒ Object
Retrieve a video by its ID for a specific project.
76 77 78 79 80 81 82 83 84 85 86 87 |
# File 'lib/videos/item/with_video_item_request_builder.rb', line 76 def to_get_request_information(request_configuration=nil) request_info = MicrosoftKiotaAbstractions::RequestInformation.new() unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.(request_configuration.) end request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :GET request_info.headers.try_add('Accept', 'application/json') return request_info end |
#with_url(raw_url) ⇒ Object
Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
93 94 95 96 |
# File 'lib/videos/item/with_video_item_request_builder.rb', line 93 def with_url(raw_url) raise StandardError, 'raw_url cannot be null' if raw_url.nil? return WithVideoItemRequestBuilder.new(raw_url, @request_adapter) end |