Class: Rixl::Models::Github_com_rixlhq_api_internal_errorsErrorResponse
- Inherits:
-
MicrosoftKiotaAbstractions::ApiError
- Object
- MicrosoftKiotaAbstractions::ApiError
- Rixl::Models::Github_com_rixlhq_api_internal_errorsErrorResponse
- Includes:
- MicrosoftKiotaAbstractions::AdditionalDataHolder, MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/models/github_com_rixlhq_api_internal_errors_error_response.rb
Overview
Standard error response returned by the API
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#additional_data ⇒ Object
Gets the AdditionalData property value.
-
#additional_data=(value) ⇒ Object
Sets the AdditionalData property value.
-
#code ⇒ Object
Gets the code property value.
-
#code=(value) ⇒ Object
Sets the code property value.
-
#details ⇒ Object
Gets the details property value.
-
#details=(value) ⇒ Object
Sets the details property value.
-
#error ⇒ Object
Gets the error property value.
-
#error=(value) ⇒ Object
Sets the error property value.
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#initialize ⇒ Object
constructor
Instantiates a new Github_com_rixlhq_api_internal_errorsErrorResponse and sets the default values.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
Constructor Details
#initialize ⇒ Object
Instantiates a new Github_com_rixlhq_api_internal_errorsErrorResponse and sets the default values.
57 58 59 60 |
# File 'lib/models/github_com_rixlhq_api_internal_errors_error_response.rb', line 57 def initialize() super @additional_data = Hash.new end |
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
66 67 68 69 |
# File 'lib/models/github_com_rixlhq_api_internal_errors_error_response.rb', line 66 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return Github_com_rixlhq_api_internal_errorsErrorResponse.new end |
Instance Method Details
#additional_data ⇒ Object
Gets the AdditionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
27 28 29 |
# File 'lib/models/github_com_rixlhq_api_internal_errors_error_response.rb', line 27 def additional_data return @additional_data end |
#additional_data=(value) ⇒ Object
Sets the AdditionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
35 36 37 |
# File 'lib/models/github_com_rixlhq_api_internal_errors_error_response.rb', line 35 def additional_data=(value) @additional_data = value end |
#code ⇒ Object
Gets the code property value. HTTP status code
42 43 44 |
# File 'lib/models/github_com_rixlhq_api_internal_errors_error_response.rb', line 42 def code return @code end |
#code=(value) ⇒ Object
Sets the code property value. HTTP status code
50 51 52 |
# File 'lib/models/github_com_rixlhq_api_internal_errors_error_response.rb', line 50 def code=(value) @code = value end |
#details ⇒ Object
Gets the details property value. Optional details about the error
74 75 76 |
# File 'lib/models/github_com_rixlhq_api_internal_errors_error_response.rb', line 74 def details return @details end |
#details=(value) ⇒ Object
Sets the details property value. Optional details about the error
82 83 84 |
# File 'lib/models/github_com_rixlhq_api_internal_errors_error_response.rb', line 82 def details=(value) @details = value end |
#error ⇒ Object
Gets the error property value. Error message describing what went wrong
89 90 91 |
# File 'lib/models/github_com_rixlhq_api_internal_errors_error_response.rb', line 89 def error return @error end |
#error=(value) ⇒ Object
Sets the error property value. Error message describing what went wrong
97 98 99 |
# File 'lib/models/github_com_rixlhq_api_internal_errors_error_response.rb', line 97 def error=(value) @error = value end |
#get_field_deserializers ⇒ Object
The deserialization information for the current model
104 105 106 107 108 109 110 |
# File 'lib/models/github_com_rixlhq_api_internal_errors_error_response.rb', line 104 def get_field_deserializers() return super.merge({ "code" => lambda {|n| @code = n.get_number_value() }, "details" => lambda {|n| @details = n.get_string_value() }, "error" => lambda {|n| @error = n.get_string_value() }, }) end |
#serialize(writer) ⇒ Object
Serializes information the current object
116 117 118 119 120 121 122 123 |
# File 'lib/models/github_com_rixlhq_api_internal_errors_error_response.rb', line 116 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? super writer.write_number_value("code", @code) writer.write_string_value("details", @details) writer.write_string_value("error", @error) writer.write_additional_data(@additional_data) end |