Class: Rixl::Models::Github_com_rixlhq_api_internal_videos_handler_uploadCompleteRequest
- Inherits:
-
Object
- Object
- Rixl::Models::Github_com_rixlhq_api_internal_videos_handler_uploadCompleteRequest
- Includes:
- MicrosoftKiotaAbstractions::AdditionalDataHolder, MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/models/github_com_rixlhq_api_internal_videos_handler_upload_complete_request.rb
Overview
Video upload completion request
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#additional_data ⇒ Object
Gets the AdditionalData property value.
-
#additional_data=(value) ⇒ Object
Sets the AdditionalData property value.
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#initialize ⇒ Object
constructor
Instantiates a new Github_com_rixlhq_api_internal_videos_handler_uploadCompleteRequest and sets the default values.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
-
#video_id ⇒ Object
Gets the video_id property value.
-
#video_id=(value) ⇒ Object
Sets the video_id property value.
Constructor Details
#initialize ⇒ Object
Instantiates a new Github_com_rixlhq_api_internal_videos_handler_uploadCompleteRequest and sets the default values.
36 37 38 |
# File 'lib/models/github_com_rixlhq_api_internal_videos_handler_upload_complete_request.rb', line 36 def initialize() @additional_data = Hash.new end |
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
44 45 46 47 |
# File 'lib/models/github_com_rixlhq_api_internal_videos_handler_upload_complete_request.rb', line 44 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return Github_com_rixlhq_api_internal_videos_handler_uploadCompleteRequest.new end |
Instance Method Details
#additional_data ⇒ Object
Gets the AdditionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
21 22 23 |
# File 'lib/models/github_com_rixlhq_api_internal_videos_handler_upload_complete_request.rb', line 21 def additional_data return @additional_data end |
#additional_data=(value) ⇒ Object
Sets the AdditionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
29 30 31 |
# File 'lib/models/github_com_rixlhq_api_internal_videos_handler_upload_complete_request.rb', line 29 def additional_data=(value) @additional_data = value end |
#get_field_deserializers ⇒ Object
The deserialization information for the current model
52 53 54 55 56 |
# File 'lib/models/github_com_rixlhq_api_internal_videos_handler_upload_complete_request.rb', line 52 def get_field_deserializers() return { "video_id" => lambda {|n| @video_id = n.get_string_value() }, } end |
#serialize(writer) ⇒ Object
Serializes information the current object
62 63 64 65 66 |
# File 'lib/models/github_com_rixlhq_api_internal_videos_handler_upload_complete_request.rb', line 62 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? writer.write_string_value("video_id", @video_id) writer.write_additional_data(@additional_data) end |
#video_id ⇒ Object
Gets the video_id property value. The video_id property
71 72 73 |
# File 'lib/models/github_com_rixlhq_api_internal_videos_handler_upload_complete_request.rb', line 71 def video_id return @video_id end |
#video_id=(value) ⇒ Object
Sets the video_id property value. The video_id property
79 80 81 |
# File 'lib/models/github_com_rixlhq_api_internal_videos_handler_upload_complete_request.rb', line 79 def video_id=(value) @video_id = value end |