Class: Rixl::Models::Image
- Inherits:
-
Object
- Object
- Rixl::Models::Image
- Includes:
- MicrosoftKiotaAbstractions::AdditionalDataHolder, MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/models/image.rb
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#additional_data ⇒ Object
Gets the AdditionalData property value.
-
#additional_data=(value) ⇒ Object
Sets the AdditionalData property value.
-
#attached_to_video ⇒ Object
Gets the attached_to_video property value.
-
#attached_to_video=(value) ⇒ Object
Sets the attached_to_video property value.
-
#file ⇒ Object
Gets the file property value.
-
#file=(value) ⇒ Object
Sets the file property value.
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#height ⇒ Object
Gets the height property value.
-
#height=(value) ⇒ Object
Sets the height property value.
-
#id ⇒ Object
Gets the id property value.
-
#id=(value) ⇒ Object
Sets the id property value.
-
#initialize ⇒ Object
constructor
Instantiates a new Image and sets the default values.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
-
#thumbhash ⇒ Object
Gets the thumbhash property value.
-
#thumbhash=(value) ⇒ Object
Sets the thumbhash property value.
-
#width ⇒ Object
Gets the width property value.
-
#width=(value) ⇒ Object
Sets the width property value.
Constructor Details
#initialize ⇒ Object
Instantiates a new Image and sets the default values.
64 65 66 |
# File 'lib/models/image.rb', line 64 def initialize() @additional_data = Hash.new end |
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
72 73 74 75 |
# File 'lib/models/image.rb', line 72 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return Image.new end |
Instance Method Details
#additional_data ⇒ Object
Gets the AdditionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
34 35 36 |
# File 'lib/models/image.rb', line 34 def additional_data return @additional_data end |
#additional_data=(value) ⇒ Object
Sets the AdditionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
42 43 44 |
# File 'lib/models/image.rb', line 42 def additional_data=(value) @additional_data = value end |
#attached_to_video ⇒ Object
Gets the attached_to_video property value. The attached_to_video property
49 50 51 |
# File 'lib/models/image.rb', line 49 def attached_to_video return @attached_to_video end |
#attached_to_video=(value) ⇒ Object
Sets the attached_to_video property value. The attached_to_video property
57 58 59 |
# File 'lib/models/image.rb', line 57 def attached_to_video=(value) @attached_to_video = value end |
#file ⇒ Object
Gets the file property value. The file property
80 81 82 |
# File 'lib/models/image.rb', line 80 def file return @file end |
#file=(value) ⇒ Object
Sets the file property value. The file property
88 89 90 |
# File 'lib/models/image.rb', line 88 def file=(value) @file = value end |
#get_field_deserializers ⇒ Object
The deserialization information for the current model
95 96 97 98 99 100 101 102 103 104 |
# File 'lib/models/image.rb', line 95 def get_field_deserializers() return { "attached_to_video" => lambda {|n| @attached_to_video = n.get_boolean_value() }, "file" => lambda {|n| @file = n.get_object_value(lambda {|pn| Rixl::Models::File.create_from_discriminator_value(pn) }) }, "height" => lambda {|n| @height = n.get_number_value() }, "id" => lambda {|n| @id = n.get_string_value() }, "thumbhash" => lambda {|n| @thumbhash = n.get_string_value() }, "width" => lambda {|n| @width = n.get_number_value() }, } end |
#height ⇒ Object
Gets the height property value. The height property
109 110 111 |
# File 'lib/models/image.rb', line 109 def height return @height end |
#height=(value) ⇒ Object
Sets the height property value. The height property
117 118 119 |
# File 'lib/models/image.rb', line 117 def height=(value) @height = value end |
#id ⇒ Object
Gets the id property value. The id property
124 125 126 |
# File 'lib/models/image.rb', line 124 def id return @id end |
#id=(value) ⇒ Object
Sets the id property value. The id property
132 133 134 |
# File 'lib/models/image.rb', line 132 def id=(value) @id = value end |
#serialize(writer) ⇒ Object
Serializes information the current object
140 141 142 143 144 145 146 147 148 149 |
# File 'lib/models/image.rb', line 140 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? writer.write_boolean_value("attached_to_video", @attached_to_video) writer.write_object_value("file", @file) writer.write_number_value("height", @height) writer.write_string_value("id", @id) writer.write_string_value("thumbhash", @thumbhash) writer.write_number_value("width", @width) writer.write_additional_data(@additional_data) end |
#thumbhash ⇒ Object
Gets the thumbhash property value. The thumbhash property
154 155 156 |
# File 'lib/models/image.rb', line 154 def thumbhash return @thumbhash end |
#thumbhash=(value) ⇒ Object
Sets the thumbhash property value. The thumbhash property
162 163 164 |
# File 'lib/models/image.rb', line 162 def thumbhash=(value) @thumbhash = value end |
#width ⇒ Object
Gets the width property value. The width property
169 170 171 |
# File 'lib/models/image.rb', line 169 def width return @width end |
#width=(value) ⇒ Object
Sets the width property value. The width property
177 178 179 |
# File 'lib/models/image.rb', line 177 def width=(value) @width = value end |