Class: Rixl::Models::Internal_images_handlerUploadInitRequest
- Inherits:
-
Object
- Object
- Rixl::Models::Internal_images_handlerUploadInitRequest
- Includes:
- MicrosoftKiotaAbstractions::AdditionalDataHolder, MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/models/internal_images_handler_upload_init_request.rb
Overview
Upload initialization request
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#additional_data ⇒ Object
Gets the AdditionalData property value.
-
#additional_data=(value) ⇒ Object
Sets the AdditionalData property value.
-
#format ⇒ Object
Gets the format property value.
-
#format=(value) ⇒ Object
Sets the format property value.
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#initialize ⇒ Object
constructor
Instantiates a new Internal_images_handlerUploadInitRequest and sets the default values.
-
#name ⇒ Object
Gets the name property value.
-
#name=(value) ⇒ Object
Sets the name property value.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
Constructor Details
#initialize ⇒ Object
Instantiates a new Internal_images_handlerUploadInitRequest and sets the default values.
39 40 41 |
# File 'lib/models/internal_images_handler_upload_init_request.rb', line 39 def initialize() @additional_data = Hash.new end |
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
47 48 49 50 |
# File 'lib/models/internal_images_handler_upload_init_request.rb', line 47 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return Internal_images_handlerUploadInitRequest.new end |
Instance Method Details
#additional_data ⇒ Object
Gets the AdditionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
24 25 26 |
# File 'lib/models/internal_images_handler_upload_init_request.rb', line 24 def additional_data return @additional_data end |
#additional_data=(value) ⇒ Object
Sets the AdditionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
32 33 34 |
# File 'lib/models/internal_images_handler_upload_init_request.rb', line 32 def additional_data=(value) @additional_data = value end |
#format ⇒ Object
Gets the format property value. The format property
55 56 57 |
# File 'lib/models/internal_images_handler_upload_init_request.rb', line 55 def format return @format end |
#format=(value) ⇒ Object
Sets the format property value. The format property
63 64 65 |
# File 'lib/models/internal_images_handler_upload_init_request.rb', line 63 def format=(value) @format = value end |
#get_field_deserializers ⇒ Object
The deserialization information for the current model
70 71 72 73 74 75 |
# File 'lib/models/internal_images_handler_upload_init_request.rb', line 70 def get_field_deserializers() return { "format" => lambda {|n| @format = n.get_string_value() }, "name" => lambda {|n| @name = n.get_string_value() }, } end |
#name ⇒ Object
Gets the name property value. The name property
80 81 82 |
# File 'lib/models/internal_images_handler_upload_init_request.rb', line 80 def name return @name end |
#name=(value) ⇒ Object
Sets the name property value. The name property
88 89 90 |
# File 'lib/models/internal_images_handler_upload_init_request.rb', line 88 def name=(value) @name = value end |
#serialize(writer) ⇒ Object
Serializes information the current object
96 97 98 99 100 101 |
# File 'lib/models/internal_images_handler_upload_init_request.rb', line 96 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? writer.write_string_value("format", @format) writer.write_string_value("name", @name) writer.write_additional_data(@additional_data) end |