Class: Rixl::Models::PaginationPagination
- Inherits:
-
Object
- Object
- Rixl::Models::PaginationPagination
- Includes:
- MicrosoftKiotaAbstractions::AdditionalDataHolder, MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/models/pagination_pagination.rb
Overview
Pagination data for the request.
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#additional_data ⇒ Object
Gets the AdditionalData property value.
-
#additional_data=(value) ⇒ Object
Sets the AdditionalData property value.
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#initialize ⇒ Object
constructor
Instantiates a new PaginationPagination and sets the default values.
-
#limit ⇒ Object
Gets the limit property value.
-
#limit=(value) ⇒ Object
Sets the limit property value.
-
#offset ⇒ Object
Gets the offset property value.
-
#offset=(value) ⇒ Object
Sets the offset property value.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
-
#total ⇒ Object
Gets the total property value.
-
#total=(value) ⇒ Object
Sets the total property value.
Constructor Details
#initialize ⇒ Object
Instantiates a new PaginationPagination and sets the default values.
42 43 44 |
# File 'lib/models/pagination_pagination.rb', line 42 def initialize() @additional_data = Hash.new end |
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
50 51 52 53 |
# File 'lib/models/pagination_pagination.rb', line 50 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return PaginationPagination.new end |
Instance Method Details
#additional_data ⇒ Object
Gets the AdditionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
27 28 29 |
# File 'lib/models/pagination_pagination.rb', line 27 def additional_data return @additional_data end |
#additional_data=(value) ⇒ Object
Sets the AdditionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
35 36 37 |
# File 'lib/models/pagination_pagination.rb', line 35 def additional_data=(value) @additional_data = value end |
#get_field_deserializers ⇒ Object
The deserialization information for the current model
58 59 60 61 62 63 64 |
# File 'lib/models/pagination_pagination.rb', line 58 def get_field_deserializers() return { "limit" => lambda {|n| @limit = n.get_number_value() }, "offset" => lambda {|n| @offset = n.get_number_value() }, "total" => lambda {|n| @total = n.get_number_value() }, } end |
#limit ⇒ Object
Gets the limit property value. Maximum number of items to return in a single request.
69 70 71 |
# File 'lib/models/pagination_pagination.rb', line 69 def limit return @limit end |
#limit=(value) ⇒ Object
Sets the limit property value. Maximum number of items to return in a single request.
77 78 79 |
# File 'lib/models/pagination_pagination.rb', line 77 def limit=(value) @limit = value end |
#offset ⇒ Object
Gets the offset property value. Starting point of the result set.
84 85 86 |
# File 'lib/models/pagination_pagination.rb', line 84 def offset return @offset end |
#offset=(value) ⇒ Object
Sets the offset property value. Starting point of the result set.
92 93 94 |
# File 'lib/models/pagination_pagination.rb', line 92 def offset=(value) @offset = value end |
#serialize(writer) ⇒ Object
Serializes information the current object
100 101 102 103 104 105 106 |
# File 'lib/models/pagination_pagination.rb', line 100 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? writer.write_number_value("limit", @limit) writer.write_number_value("offset", @offset) writer.write_number_value("total", @total) writer.write_additional_data(@additional_data) end |
#total ⇒ Object
Gets the total property value. The total number of available items in the full list.
111 112 113 |
# File 'lib/models/pagination_pagination.rb', line 111 def total return @total end |
#total=(value) ⇒ Object
Sets the total property value. The total number of available items in the full list.
119 120 121 |
# File 'lib/models/pagination_pagination.rb', line 119 def total=(value) @total = value end |