Class: Rixl::Models::UpdateChaptersRequest
- Inherits:
-
Object
- Object
- Rixl::Models::UpdateChaptersRequest
- Includes:
- MicrosoftKiotaAbstractions::AdditionalDataHolder, MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/models/update_chapters_request.rb
Overview
Chapters array
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#additional_data ⇒ Object
Gets the AdditionalData property value.
-
#additional_data=(value) ⇒ Object
Sets the AdditionalData property value.
-
#chapters ⇒ Object
Gets the chapters property value.
-
#chapters=(value) ⇒ Object
Sets the chapters property value.
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#initialize ⇒ Object
constructor
Instantiates a new UpdateChaptersRequest and sets the default values.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
Constructor Details
#initialize ⇒ Object
Instantiates a new UpdateChaptersRequest and sets the default values.
51 52 53 |
# File 'lib/models/update_chapters_request.rb', line 51 def initialize() @additional_data = Hash.new end |
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
59 60 61 62 |
# File 'lib/models/update_chapters_request.rb', line 59 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return UpdateChaptersRequest.new end |
Instance Method Details
#additional_data ⇒ Object
Gets the AdditionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
21 22 23 |
# File 'lib/models/update_chapters_request.rb', line 21 def additional_data return @additional_data end |
#additional_data=(value) ⇒ Object
Sets the AdditionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
29 30 31 |
# File 'lib/models/update_chapters_request.rb', line 29 def additional_data=(value) @additional_data = value end |
#chapters ⇒ Object
Gets the chapters property value. The chapters property
36 37 38 |
# File 'lib/models/update_chapters_request.rb', line 36 def chapters return @chapters end |
#chapters=(value) ⇒ Object
Sets the chapters property value. The chapters property
44 45 46 |
# File 'lib/models/update_chapters_request.rb', line 44 def chapters=(value) @chapters = value end |
#get_field_deserializers ⇒ Object
The deserialization information for the current model
67 68 69 70 71 |
# File 'lib/models/update_chapters_request.rb', line 67 def get_field_deserializers() return { "chapters" => lambda {|n| @chapters = n.get_collection_of_object_values(lambda {|pn| Rixl::Models::Github_com_rixlhq_api_internal_videos_typesChapterInput.create_from_discriminator_value(pn) }) }, } end |
#serialize(writer) ⇒ Object
Serializes information the current object
77 78 79 80 81 |
# File 'lib/models/update_chapters_request.rb', line 77 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? writer.write_collection_of_object_values("chapters", @chapters) writer.write_additional_data(@additional_data) end |