Class: Rixl::Models::Video
- Inherits:
-
Object
- Object
- Rixl::Models::Video
- Includes:
- MicrosoftKiotaAbstractions::AdditionalDataHolder, MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/models/video.rb
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#additional_data ⇒ Object
Gets the AdditionalData property value.
-
#additional_data=(value) ⇒ Object
Sets the AdditionalData property value.
-
#bitrate ⇒ Object
Gets the bitrate property value.
-
#bitrate=(value) ⇒ Object
Sets the bitrate property value.
-
#chapters ⇒ Object
Gets the chapters property value.
-
#chapters=(value) ⇒ Object
Sets the chapters property value.
-
#codec ⇒ Object
Gets the codec property value.
-
#codec=(value) ⇒ Object
Sets the codec property value.
-
#duration ⇒ Object
Gets the duration property value.
-
#duration=(value) ⇒ Object
Sets the duration property value.
-
#file ⇒ Object
Gets the file property value.
-
#file=(value) ⇒ Object
Sets the file property value.
-
#framerate ⇒ Object
Gets the framerate property value.
-
#framerate=(value) ⇒ Object
Sets the framerate property value.
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#hdr ⇒ Object
Gets the hdr property value.
-
#hdr=(value) ⇒ Object
Sets the hdr property value.
-
#height ⇒ Object
Gets the height property value.
-
#height=(value) ⇒ Object
Sets the height property value.
-
#id ⇒ Object
Gets the id property value.
-
#id=(value) ⇒ Object
Sets the id property value.
-
#initialize ⇒ Object
constructor
Instantiates a new Video and sets the default values.
-
#plan_type ⇒ Object
Gets the plan_type property value.
-
#plan_type=(value) ⇒ Object
Sets the plan_type property value.
-
#poster ⇒ Object
Gets the poster property value.
-
#poster=(value) ⇒ Object
Sets the poster property value.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
-
#width ⇒ Object
Gets the width property value.
-
#width=(value) ⇒ Object
Sets the width property value.
Constructor Details
#initialize ⇒ Object
Instantiates a new Video and sets the default values.
112 113 114 |
# File 'lib/models/video.rb', line 112 def initialize() @additional_data = Hash.new end |
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
120 121 122 123 |
# File 'lib/models/video.rb', line 120 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return Video.new end |
Instance Method Details
#additional_data ⇒ Object
Gets the AdditionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
52 53 54 |
# File 'lib/models/video.rb', line 52 def additional_data return @additional_data end |
#additional_data=(value) ⇒ Object
Sets the AdditionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
60 61 62 |
# File 'lib/models/video.rb', line 60 def additional_data=(value) @additional_data = value end |
#bitrate ⇒ Object
Gets the bitrate property value. The bitrate property
67 68 69 |
# File 'lib/models/video.rb', line 67 def bitrate return @bitrate end |
#bitrate=(value) ⇒ Object
Sets the bitrate property value. The bitrate property
75 76 77 |
# File 'lib/models/video.rb', line 75 def bitrate=(value) @bitrate = value end |
#chapters ⇒ Object
Gets the chapters property value. The chapters property
82 83 84 |
# File 'lib/models/video.rb', line 82 def chapters return @chapters end |
#chapters=(value) ⇒ Object
Sets the chapters property value. The chapters property
90 91 92 |
# File 'lib/models/video.rb', line 90 def chapters=(value) @chapters = value end |
#codec ⇒ Object
Gets the codec property value. The codec property
97 98 99 |
# File 'lib/models/video.rb', line 97 def codec return @codec end |
#codec=(value) ⇒ Object
Sets the codec property value. The codec property
105 106 107 |
# File 'lib/models/video.rb', line 105 def codec=(value) @codec = value end |
#duration ⇒ Object
Gets the duration property value. The duration property
128 129 130 |
# File 'lib/models/video.rb', line 128 def duration return @duration end |
#duration=(value) ⇒ Object
Sets the duration property value. The duration property
136 137 138 |
# File 'lib/models/video.rb', line 136 def duration=(value) @duration = value end |
#file ⇒ Object
Gets the file property value. The file property
143 144 145 |
# File 'lib/models/video.rb', line 143 def file return @file end |
#file=(value) ⇒ Object
Sets the file property value. The file property
151 152 153 |
# File 'lib/models/video.rb', line 151 def file=(value) @file = value end |
#framerate ⇒ Object
Gets the framerate property value. The framerate property
158 159 160 |
# File 'lib/models/video.rb', line 158 def framerate return @framerate end |
#framerate=(value) ⇒ Object
Sets the framerate property value. The framerate property
166 167 168 |
# File 'lib/models/video.rb', line 166 def framerate=(value) @framerate = value end |
#get_field_deserializers ⇒ Object
The deserialization information for the current model
173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 |
# File 'lib/models/video.rb', line 173 def get_field_deserializers() return { "bitrate" => lambda {|n| @bitrate = n.get_number_value() }, "chapters" => lambda {|n| @chapters = n.get_collection_of_object_values(lambda {|pn| Rixl::Models::Chapter.create_from_discriminator_value(pn) }) }, "codec" => lambda {|n| @codec = n.get_string_value() }, "duration" => lambda {|n| @duration = n.get_object_value(lambda {|pn| Double.create_from_discriminator_value(pn) }) }, "file" => lambda {|n| @file = n.get_object_value(lambda {|pn| Rixl::Models::File.create_from_discriminator_value(pn) }) }, "framerate" => lambda {|n| @framerate = n.get_string_value() }, "hdr" => lambda {|n| @hdr = n.get_boolean_value() }, "height" => lambda {|n| @height = n.get_number_value() }, "id" => lambda {|n| @id = n.get_string_value() }, "plan_type" => lambda {|n| @plan_type = n.get_enum_value(Rixl::Models::Github_com_rixlhq_api_db_sqlcPlanType) }, "poster" => lambda {|n| @poster = n.get_object_value(lambda {|pn| Rixl::Models::Image.create_from_discriminator_value(pn) }) }, "width" => lambda {|n| @width = n.get_number_value() }, } end |
#hdr ⇒ Object
Gets the hdr property value. The hdr property
193 194 195 |
# File 'lib/models/video.rb', line 193 def hdr return @hdr end |
#hdr=(value) ⇒ Object
Sets the hdr property value. The hdr property
201 202 203 |
# File 'lib/models/video.rb', line 201 def hdr=(value) @hdr = value end |
#height ⇒ Object
Gets the height property value. The height property
208 209 210 |
# File 'lib/models/video.rb', line 208 def height return @height end |
#height=(value) ⇒ Object
Sets the height property value. The height property
216 217 218 |
# File 'lib/models/video.rb', line 216 def height=(value) @height = value end |
#id ⇒ Object
Gets the id property value. The id property
223 224 225 |
# File 'lib/models/video.rb', line 223 def id return @id end |
#id=(value) ⇒ Object
Sets the id property value. The id property
231 232 233 |
# File 'lib/models/video.rb', line 231 def id=(value) @id = value end |
#plan_type ⇒ Object
Gets the plan_type property value. The plan_type property
238 239 240 |
# File 'lib/models/video.rb', line 238 def plan_type return @plan_type end |
#plan_type=(value) ⇒ Object
Sets the plan_type property value. The plan_type property
246 247 248 |
# File 'lib/models/video.rb', line 246 def plan_type=(value) @plan_type = value end |
#poster ⇒ Object
Gets the poster property value. The poster property
253 254 255 |
# File 'lib/models/video.rb', line 253 def poster return @poster end |
#poster=(value) ⇒ Object
Sets the poster property value. The poster property
261 262 263 |
# File 'lib/models/video.rb', line 261 def poster=(value) @poster = value end |
#serialize(writer) ⇒ Object
Serializes information the current object
269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 |
# File 'lib/models/video.rb', line 269 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? writer.write_number_value("bitrate", @bitrate) writer.write_collection_of_object_values("chapters", @chapters) writer.write_string_value("codec", @codec) writer.write_object_value("duration", @duration) writer.write_object_value("file", @file) writer.write_string_value("framerate", @framerate) writer.write_boolean_value("hdr", @hdr) writer.write_number_value("height", @height) writer.write_string_value("id", @id) writer.write_enum_value("plan_type", @plan_type) writer.write_object_value("poster", @poster) writer.write_number_value("width", @width) writer.write_additional_data(@additional_data) end |
#width ⇒ Object
Gets the width property value. The width property
289 290 291 |
# File 'lib/models/video.rb', line 289 def width return @width end |
#width=(value) ⇒ Object
Sets the width property value. The width property
297 298 299 |
# File 'lib/models/video.rb', line 297 def width=(value) @width = value end |